<?php
/**
 * Typo3 Extension paypal_subscription
 * PayPal Subscriptions based on extensions cart and cart_products to enable recurring transactions
 * Copyright (C) 2019  Andreas Sommer <sommer@belsignum.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
namespace Belsignum\PaypalSubscription\Utility;

class TcaUtility
{

	/**
	 * LLL path
	 * @return string
	 */
	protected static function LLL():string
	{
		return 'LLL:EXT:paypal_subscription/Resources/Private/Language/locallang_db.xlf';
	}

	/**
	 * returns the paypal types
	 *
	 * @return array
	 */
	public static function paypalTypes():array
	{
		$LLL = self::LLL();
		return [
			[$LLL . ':tx_cartproducts_paypal.type.digital', 'digital'],
			[$LLL . ':tx_cartproducts_paypal.type.service', 'service'],
			[$LLL . ':tx_cartproducts_paypal.type.physical', 'physical'],
		];
	}

	/**
	 * returns the paypal categories
	 *
	 * @return array
	 */
	public static function paypalCategories():array
	{
		$LLL = self::LLL();
		return [
			[$LLL . ':tx_cartproducts_paypal.category.ac_refrigeration_repair', 'ac_refrigeration_repair'],
			[$LLL . ':tx_cartproducts_paypal.category.academic_software', 'academic_software'],
			[$LLL . ':tx_cartproducts_paypal.category.accessories', 'accessories'],
			[$LLL . ':tx_cartproducts_paypal.category.accounting', 'accounting'],
			[$LLL . ':tx_cartproducts_paypal.category.adult', 'adult'],
			[$LLL . ':tx_cartproducts_paypal.category.advertising', 'advertising'],
			[$LLL . ':tx_cartproducts_paypal.category.affiliated_auto_rental', 'affiliated_auto_rental'],
			[$LLL . ':tx_cartproducts_paypal.category.agencies', 'agencies'],
			[$LLL . ':tx_cartproducts_paypal.category.aggregators', 'aggregators'],
			[$LLL . ':tx_cartproducts_paypal.category.agricultural_cooperative_for_mail_order', 'agricultural_cooperative_for_mail_order'],
			[$LLL . ':tx_cartproducts_paypal.category.air_carriers_airlines', 'air_carriers_airlines'],
			[$LLL . ':tx_cartproducts_paypal.category.airlines', 'airlines'],
			[$LLL . ':tx_cartproducts_paypal.category.airports_flying_fields', 'airports_flying_fields'],
			[$LLL . ':tx_cartproducts_paypal.category.alcoholic_beverages', 'alcoholic_beverages'],
			[$LLL . ':tx_cartproducts_paypal.category.amusement_parks_carnivals', 'amusement_parks_carnivals'],
			[$LLL . ':tx_cartproducts_paypal.category.animation', 'animation'],
			[$LLL . ':tx_cartproducts_paypal.category.antiques', 'antiques'],
			[$LLL . ':tx_cartproducts_paypal.category.appliances', 'appliances'],
			[$LLL . ':tx_cartproducts_paypal.category.aquariams_seaquariums_dolphinariums', 'aquariams_seaquariums_dolphinariums'],
			[$LLL . ':tx_cartproducts_paypal.category.architectural_engineering_and_surveying_services', 'architectural_engineering_and_surveying_services'],
			[$LLL . ':tx_cartproducts_paypal.category.art_and_craft_supplies', 'art_and_craft_supplies'],
			[$LLL . ':tx_cartproducts_paypal.category.art_dealers_and_galleries', 'art_dealers_and_galleries'],
			[$LLL . ':tx_cartproducts_paypal.category.artifacts_grave_related_and_native_american_crafts', 'artifacts_grave_related_and_native_american_crafts'],
			[$LLL . ':tx_cartproducts_paypal.category.arts_and_crafts', 'arts_and_crafts'],
			[$LLL . ':tx_cartproducts_paypal.category.arts_crafts_and_collectibles', 'arts_crafts_and_collectibles'],
			[$LLL . ':tx_cartproducts_paypal.category.audio_books', 'audio_books'],
			[$LLL . ':tx_cartproducts_paypal.category.auto_associations_clubs', 'auto_associations_clubs'],
			[$LLL . ':tx_cartproducts_paypal.category.auto_dealer_used_only', 'auto_dealer_used_only'],
			[$LLL . ':tx_cartproducts_paypal.category.auto_rentals', 'auto_rentals'],
			[$LLL . ':tx_cartproducts_paypal.category.auto_service', 'auto_service'],
			[$LLL . ':tx_cartproducts_paypal.category.automated_fuel_dispensers', 'automated_fuel_dispensers'],
			[$LLL . ':tx_cartproducts_paypal.category.automobile_associations', 'automobile_associations'],
			[$LLL . ':tx_cartproducts_paypal.category.automotive', 'automotive'],
			[$LLL . ':tx_cartproducts_paypal.category.automotive_repair_shops_non_dealer', 'automotive_repair_shops_non_dealer'],
			[$LLL . ':tx_cartproducts_paypal.category.automotive_top_and_body_shops', 'automotive_top_and_body_shops'],
			[$LLL . ':tx_cartproducts_paypal.category.aviation', 'aviation'],
			[$LLL . ':tx_cartproducts_paypal.category.babies_clothing_and_supplies', 'babies_clothing_and_supplies'],
			[$LLL . ':tx_cartproducts_paypal.category.baby', 'baby'],
			[$LLL . ':tx_cartproducts_paypal.category.bands_orchestras_entertainers', 'bands_orchestras_entertainers'],
			[$LLL . ':tx_cartproducts_paypal.category.barbies', 'barbies'],
			[$LLL . ':tx_cartproducts_paypal.category.bath_and_body', 'bath_and_body'],
			[$LLL . ':tx_cartproducts_paypal.category.batteries', 'batteries'],
			[$LLL . ':tx_cartproducts_paypal.category.bean_babies', 'bean_babies'],
			[$LLL . ':tx_cartproducts_paypal.category.beauty', 'beauty'],
			[$LLL . ':tx_cartproducts_paypal.category.beauty_and_fragrances', 'beauty_and_fragrances'],
			[$LLL . ':tx_cartproducts_paypal.category.bed_and_bath', 'bed_and_bath'],
			[$LLL . ':tx_cartproducts_paypal.category.bicycle_shops_sales_and_service', 'bicycle_shops_sales_and_service'],
			[$LLL . ':tx_cartproducts_paypal.category.bicycles_and_accessories', 'bicycles_and_accessories'],
			[$LLL . ':tx_cartproducts_paypal.category.billiard_pool_establishments', 'billiard_pool_establishments'],
			[$LLL . ':tx_cartproducts_paypal.category.boat_dealers', 'boat_dealers'],
			[$LLL . ':tx_cartproducts_paypal.category.boat_rentals_and_leasing', 'boat_rentals_and_leasing'],
			[$LLL . ':tx_cartproducts_paypal.category.boating_sailing_and_accessories', 'boating_sailing_and_accessories'],
			[$LLL . ':tx_cartproducts_paypal.category.books', 'books'],
			[$LLL . ':tx_cartproducts_paypal.category.books_and_magazines', 'books_and_magazines'],
			[$LLL . ':tx_cartproducts_paypal.category.books_manuscripts', 'books_manuscripts'],
			[$LLL . ':tx_cartproducts_paypal.category.books_periodicals_and_newspapers', 'books_periodicals_and_newspapers'],
			[$LLL . ':tx_cartproducts_paypal.category.bowling_alleys', 'bowling_alleys'],
			[$LLL . ':tx_cartproducts_paypal.category.bulletin_board', 'bulletin_board'],
			[$LLL . ':tx_cartproducts_paypal.category.bus_line', 'bus_line'],
			[$LLL . ':tx_cartproducts_paypal.category.bus_lines_charters_tour_buses', 'bus_lines_charters_tour_buses'],
			[$LLL . ':tx_cartproducts_paypal.category.business', 'business'],
			[$LLL . ':tx_cartproducts_paypal.category.business_and_secretarial_schools', 'business_and_secretarial_schools'],
			[$LLL . ':tx_cartproducts_paypal.category.buying_and_shopping_services_and_clubs', 'buying_and_shopping_services_and_clubs'],
			[$LLL . ':tx_cartproducts_paypal.category.cable_satellite_and_other_pay_television_and_radio_services', 'cable_satellite_and_other_pay_television_and_radio_services'],
			[$LLL . ':tx_cartproducts_paypal.category.cable_satellite_and_other_pay_tv_and_radio', 'cable_satellite_and_other_pay_tv_and_radio'],
			[$LLL . ':tx_cartproducts_paypal.category.camera_and_photographic_supplies', 'camera_and_photographic_supplies'],
			[$LLL . ':tx_cartproducts_paypal.category.cameras', 'cameras'],
			[$LLL . ':tx_cartproducts_paypal.category.cameras_and_photography', 'cameras_and_photography'],
			[$LLL . ':tx_cartproducts_paypal.category.camper_recreational_and_utility_trailer_dealers', 'camper_recreational_and_utility_trailer_dealers'],
			[$LLL . ':tx_cartproducts_paypal.category.camping_and_outdoors', 'camping_and_outdoors'],
			[$LLL . ':tx_cartproducts_paypal.category.camping_and_survival', 'camping_and_survival'],
			[$LLL . ':tx_cartproducts_paypal.category.car_and_truck_dealers', 'car_and_truck_dealers'],
			[$LLL . ':tx_cartproducts_paypal.category.car_and_truck_dealers_used_only', 'car_and_truck_dealers_used_only'],
			[$LLL . ':tx_cartproducts_paypal.category.car_audio_and_electronics', 'car_audio_and_electronics'],
			[$LLL . ':tx_cartproducts_paypal.category.car_rental_agency', 'car_rental_agency'],
			[$LLL . ':tx_cartproducts_paypal.category.catalog_merchant', 'catalog_merchant'],
			[$LLL . ':tx_cartproducts_paypal.category.catalog_retail_merchant', 'catalog_retail_merchant'],
			[$LLL . ':tx_cartproducts_paypal.category.catering_services', 'catering_services'],
			[$LLL . ':tx_cartproducts_paypal.category.charity', 'charity'],
			[$LLL . ':tx_cartproducts_paypal.category.check_cashier', 'check_cashier'],
			[$LLL . ':tx_cartproducts_paypal.category.child_care_services', 'child_care_services'],
			[$LLL . ':tx_cartproducts_paypal.category.children_books', 'children_books'],
			[$LLL . ':tx_cartproducts_paypal.category.chiropodists_podiatrists', 'chiropodists_podiatrists'],
			[$LLL . ':tx_cartproducts_paypal.category.chiropractors', 'chiropractors'],
			[$LLL . ':tx_cartproducts_paypal.category.cigar_stores_and_stands', 'cigar_stores_and_stands'],
			[$LLL . ':tx_cartproducts_paypal.category.civic_social_fraternal_associations', 'civic_social_fraternal_associations'],
			[$LLL . ':tx_cartproducts_paypal.category.civil_social_frat_associations', 'civil_social_frat_associations'],
			[$LLL . ':tx_cartproducts_paypal.category.clothing', 'clothing'],
			[$LLL . ':tx_cartproducts_paypal.category.clothing_accessories_and_shoes', 'clothing_accessories_and_shoes'],
			[$LLL . ':tx_cartproducts_paypal.category.clothing_rental', 'clothing_rental'],
			[$LLL . ':tx_cartproducts_paypal.category.coffee_and_tea', 'coffee_and_tea'],
			[$LLL . ':tx_cartproducts_paypal.category.coin_operated_banks_and_casinos', 'coin_operated_banks_and_casinos'],
			[$LLL . ':tx_cartproducts_paypal.category.collectibles', 'collectibles'],
			[$LLL . ':tx_cartproducts_paypal.category.collection_agency', 'collection_agency'],
			[$LLL . ':tx_cartproducts_paypal.category.colleges_and_universities', 'colleges_and_universities'],
			[$LLL . ':tx_cartproducts_paypal.category.commercial_equipment', 'commercial_equipment'],
			[$LLL . ':tx_cartproducts_paypal.category.commercial_footwear', 'commercial_footwear'],
			[$LLL . ':tx_cartproducts_paypal.category.commercial_photography', 'commercial_photography'],
			[$LLL . ':tx_cartproducts_paypal.category.commercial_photography_art_and_graphics', 'commercial_photography_art_and_graphics'],
			[$LLL . ':tx_cartproducts_paypal.category.commercial_sports_professiona', 'commercial_sports_professiona'],
			[$LLL . ':tx_cartproducts_paypal.category.commodities_and_futures_exchange', 'commodities_and_futures_exchange'],
			[$LLL . ':tx_cartproducts_paypal.category.computer_and_data_processing_services', 'computer_and_data_processing_services'],
			[$LLL . ':tx_cartproducts_paypal.category.computer_hardware_and_software', 'computer_hardware_and_software'],
			[$LLL . ':tx_cartproducts_paypal.category.computer_maintenance_repair_and_services_not_elsewhere_clas', 'computer_maintenance_repair_and_services_not_elsewhere_clas'],
			[$LLL . ':tx_cartproducts_paypal.category.construction', 'construction'],
			[$LLL . ':tx_cartproducts_paypal.category.construction_materials_not_elsewhere_classified', 'construction_materials_not_elsewhere_classified'],
			[$LLL . ':tx_cartproducts_paypal.category.consulting_services', 'consulting_services'],
			[$LLL . ':tx_cartproducts_paypal.category.consumer_credit_reporting_agencies', 'consumer_credit_reporting_agencies'],
			[$LLL . ':tx_cartproducts_paypal.category.convalescent_homes', 'convalescent_homes'],
			[$LLL . ':tx_cartproducts_paypal.category.cosmetic_stores', 'cosmetic_stores'],
			[$LLL . ':tx_cartproducts_paypal.category.counseling_services_debt_marriage_personal', 'counseling_services_debt_marriage_personal'],
			[$LLL . ':tx_cartproducts_paypal.category.counterfeit_currency_and_stamps', 'counterfeit_currency_and_stamps'],
			[$LLL . ':tx_cartproducts_paypal.category.counterfeit_items', 'counterfeit_items'],
			[$LLL . ':tx_cartproducts_paypal.category.country_clubs', 'country_clubs'],
			[$LLL . ':tx_cartproducts_paypal.category.courier_services', 'courier_services'],
			[$LLL . ':tx_cartproducts_paypal.category.courier_services_air_and_ground_and_freight_forwarders', 'courier_services_air_and_ground_and_freight_forwarders'],
			[$LLL . ':tx_cartproducts_paypal.category.court_costs_alimny_child_supt', 'court_costs_alimny_child_supt'],
			[$LLL . ':tx_cartproducts_paypal.category.court_costs_including_alimony_and_child_support_courts_of_law', 'court_costs_including_alimony_and_child_support_courts_of_law'],
			[$LLL . ':tx_cartproducts_paypal.category.credit_cards', 'credit_cards'],
			[$LLL . ':tx_cartproducts_paypal.category.credit_union', 'credit_union'],
			[$LLL . ':tx_cartproducts_paypal.category.culture_and_religion', 'culture_and_religion'],
			[$LLL . ':tx_cartproducts_paypal.category.dairy_products_stores', 'dairy_products_stores'],
			[$LLL . ':tx_cartproducts_paypal.category.dance_halls_studios_and_schools', 'dance_halls_studios_and_schools'],
			[$LLL . ':tx_cartproducts_paypal.category.decorative', 'decorative'],
			[$LLL . ':tx_cartproducts_paypal.category.dental', 'dental'],
			[$LLL . ':tx_cartproducts_paypal.category.dentists_and_orthodontists', 'dentists_and_orthodontists'],
			[$LLL . ':tx_cartproducts_paypal.category.department_stores', 'department_stores'],
			[$LLL . ':tx_cartproducts_paypal.category.desktop_pcs', 'desktop_pcs'],
			[$LLL . ':tx_cartproducts_paypal.category.devices', 'devices'],
			[$LLL . ':tx_cartproducts_paypal.category.diecast_toys_vehicles', 'diecast_toys_vehicles'],
			[$LLL . ':tx_cartproducts_paypal.category.digital_games', 'digital_games'],
			[$LLL . ':tx_cartproducts_paypal.category.digital_media_books_movies_music', 'digital_media_books_movies_music'],
			[$LLL . ':tx_cartproducts_paypal.category.direct_marketing', 'direct_marketing'],
			[$LLL . ':tx_cartproducts_paypal.category.direct_marketing_catalog_merchant', 'direct_marketing_catalog_merchant'],
			[$LLL . ':tx_cartproducts_paypal.category.direct_marketing_inbound_tele', 'direct_marketing_inbound_tele'],
			[$LLL . ':tx_cartproducts_paypal.category.direct_marketing_outbound_tele', 'direct_marketing_outbound_tele'],
			[$LLL . ':tx_cartproducts_paypal.category.direct_marketing_subscription', 'direct_marketing_subscription'],
			[$LLL . ':tx_cartproducts_paypal.category.discount_stores', 'discount_stores'],
			[$LLL . ':tx_cartproducts_paypal.category.door_to_door_sales', 'door_to_door_sales'],
			[$LLL . ':tx_cartproducts_paypal.category.drapery_window_covering_and_upholstery', 'drapery_window_covering_and_upholstery'],
			[$LLL . ':tx_cartproducts_paypal.category.drinking_places', 'drinking_places'],
			[$LLL . ':tx_cartproducts_paypal.category.drugstore', 'drugstore'],
			[$LLL . ':tx_cartproducts_paypal.category.durable_goods', 'durable_goods'],
			[$LLL . ':tx_cartproducts_paypal.category.ecommerce_development', 'ecommerce_development'],
			[$LLL . ':tx_cartproducts_paypal.category.ecommerce_services', 'ecommerce_services'],
			[$LLL . ':tx_cartproducts_paypal.category.educational_and_textbooks', 'educational_and_textbooks'],
			[$LLL . ':tx_cartproducts_paypal.category.electric_razor_stores', 'electric_razor_stores'],
			[$LLL . ':tx_cartproducts_paypal.category.electrical_and_small_appliance_repair', 'electrical_and_small_appliance_repair'],
			[$LLL . ':tx_cartproducts_paypal.category.electrical_contractors', 'electrical_contractors'],
			[$LLL . ':tx_cartproducts_paypal.category.electrical_parts_and_equipment', 'electrical_parts_and_equipment'],
			[$LLL . ':tx_cartproducts_paypal.category.electronic_cash', 'electronic_cash'],
			[$LLL . ':tx_cartproducts_paypal.category.elementary_and_secondary_schools', 'elementary_and_secondary_schools'],
			[$LLL . ':tx_cartproducts_paypal.category.employment', 'employment'],
			[$LLL . ':tx_cartproducts_paypal.category.entertainers', 'entertainers'],
			[$LLL . ':tx_cartproducts_paypal.category.entertainment_and_media', 'entertainment_and_media'],
			[$LLL . ':tx_cartproducts_paypal.category.equip_tool_furniture_and_appliance_rental_and_leasing', 'equip_tool_furniture_and_appliance_rental_and_leasing'],
			[$LLL . ':tx_cartproducts_paypal.category.escrow', 'escrow'],
			[$LLL . ':tx_cartproducts_paypal.category.event_and_wedding_planning', 'event_and_wedding_planning'],
			[$LLL . ':tx_cartproducts_paypal.category.exercise_and_fitness', 'exercise_and_fitness'],
			[$LLL . ':tx_cartproducts_paypal.category.exercise_equipment', 'exercise_equipment'],
			[$LLL . ':tx_cartproducts_paypal.category.exterminating_and_disinfecting_services', 'exterminating_and_disinfecting_services'],
			[$LLL . ':tx_cartproducts_paypal.category.fabrics_and_sewing', 'fabrics_and_sewing'],
			[$LLL . ':tx_cartproducts_paypal.category.family_clothing_stores', 'family_clothing_stores'],
			[$LLL . ':tx_cartproducts_paypal.category.fashion_jewelry', 'fashion_jewelry'],
			[$LLL . ':tx_cartproducts_paypal.category.fast_food_restaurants', 'fast_food_restaurants'],
			[$LLL . ':tx_cartproducts_paypal.category.fiction_and_nonfiction', 'fiction_and_nonfiction'],
			[$LLL . ':tx_cartproducts_paypal.category.finance_company', 'finance_company'],
			[$LLL . ':tx_cartproducts_paypal.category.financial_and_investment_advice', 'financial_and_investment_advice'],
			[$LLL . ':tx_cartproducts_paypal.category.financial_institutions_merchandise_and_services', 'financial_institutions_merchandise_and_services'],
			[$LLL . ':tx_cartproducts_paypal.category.firearm_accessories', 'firearm_accessories'],
			[$LLL . ':tx_cartproducts_paypal.category.firearms_weapons_and_knives', 'firearms_weapons_and_knives'],
			[$LLL . ':tx_cartproducts_paypal.category.fireplace_and_fireplace_screens', 'fireplace_and_fireplace_screens'],
			[$LLL . ':tx_cartproducts_paypal.category.fireworks', 'fireworks'],
			[$LLL . ':tx_cartproducts_paypal.category.fishing', 'fishing'],
			[$LLL . ':tx_cartproducts_paypal.category.florists', 'florists'],
			[$LLL . ':tx_cartproducts_paypal.category.flowers', 'flowers'],
			[$LLL . ':tx_cartproducts_paypal.category.food_drink_and_nutrition', 'food_drink_and_nutrition'],
			[$LLL . ':tx_cartproducts_paypal.category.food_products', 'food_products'],
			[$LLL . ':tx_cartproducts_paypal.category.food_retail_and_service', 'food_retail_and_service'],
			[$LLL . ':tx_cartproducts_paypal.category.fragrances_and_perfumes', 'fragrances_and_perfumes'],
			[$LLL . ':tx_cartproducts_paypal.category.freezer_and_locker_meat_provisioners', 'freezer_and_locker_meat_provisioners'],
			[$LLL . ':tx_cartproducts_paypal.category.fuel_dealers_fuel_oil_wood_and_coal', 'fuel_dealers_fuel_oil_wood_and_coal'],
			[$LLL . ':tx_cartproducts_paypal.category.fuel_dealers_non_automotive', 'fuel_dealers_non_automotive'],
			[$LLL . ':tx_cartproducts_paypal.category.funeral_services_and_crematories', 'funeral_services_and_crematories'],
			[$LLL . ':tx_cartproducts_paypal.category.furnishing_and_decorating', 'furnishing_and_decorating'],
			[$LLL . ':tx_cartproducts_paypal.category.furniture', 'furniture'],
			[$LLL . ':tx_cartproducts_paypal.category.furriers_and_fur_shops', 'furriers_and_fur_shops'],
			[$LLL . ':tx_cartproducts_paypal.category.gadgets_and_other_electronics', 'gadgets_and_other_electronics'],
			[$LLL . ':tx_cartproducts_paypal.category.gambling', 'gambling'],
			[$LLL . ':tx_cartproducts_paypal.category.game_software', 'game_software'],
			[$LLL . ':tx_cartproducts_paypal.category.games', 'games'],
			[$LLL . ':tx_cartproducts_paypal.category.garden_supplies', 'garden_supplies'],
			[$LLL . ':tx_cartproducts_paypal.category.general', 'general'],
			[$LLL . ':tx_cartproducts_paypal.category.general_contractors', 'general_contractors'],
			[$LLL . ':tx_cartproducts_paypal.category.general_government', 'general_government'],
			[$LLL . ':tx_cartproducts_paypal.category.general_software', 'general_software'],
			[$LLL . ':tx_cartproducts_paypal.category.general_telecom', 'general_telecom'],
			[$LLL . ':tx_cartproducts_paypal.category.gifts_and_flowers', 'gifts_and_flowers'],
			[$LLL . ':tx_cartproducts_paypal.category.glass_paint_and_wallpaper_stores', 'glass_paint_and_wallpaper_stores'],
			[$LLL . ':tx_cartproducts_paypal.category.glassware_crystal_stores', 'glassware_crystal_stores'],
			[$LLL . ':tx_cartproducts_paypal.category.government', 'government'],
			[$LLL . ':tx_cartproducts_paypal.category.government_ids_and_licenses', 'government_ids_and_licenses'],
			[$LLL . ':tx_cartproducts_paypal.category.government_licensed_on_line_casinos_on_line_gambling', 'government_licensed_on_line_casinos_on_line_gambling'],
			[$LLL . ':tx_cartproducts_paypal.category.government_owned_lotteries', 'government_owned_lotteries'],
			[$LLL . ':tx_cartproducts_paypal.category.government_services', 'government_services'],
			[$LLL . ':tx_cartproducts_paypal.category.graphic_and_commercial_design', 'graphic_and_commercial_design'],
			[$LLL . ':tx_cartproducts_paypal.category.greeting_cards', 'greeting_cards'],
			[$LLL . ':tx_cartproducts_paypal.category.grocery_stores_and_supermarkets', 'grocery_stores_and_supermarkets'],
			[$LLL . ':tx_cartproducts_paypal.category.hardware_and_tools', 'hardware_and_tools'],
			[$LLL . ':tx_cartproducts_paypal.category.hardware_equipment_and_supplies', 'hardware_equipment_and_supplies'],
			[$LLL . ':tx_cartproducts_paypal.category.hazardous_restricted_and_perishable_items', 'hazardous_restricted_and_perishable_items'],
			[$LLL . ':tx_cartproducts_paypal.category.health_and_beauty_spas', 'health_and_beauty_spas'],
			[$LLL . ':tx_cartproducts_paypal.category.health_and_nutrition', 'health_and_nutrition'],
			[$LLL . ':tx_cartproducts_paypal.category.health_and_personal_care', 'health_and_personal_care'],
			[$LLL . ':tx_cartproducts_paypal.category.hearing_aids_sales_and_supplies', 'hearing_aids_sales_and_supplies'],
			[$LLL . ':tx_cartproducts_paypal.category.heating_plumbing_ac', 'heating_plumbing_ac'],
			[$LLL . ':tx_cartproducts_paypal.category.high_risk_merchant', 'high_risk_merchant'],
			[$LLL . ':tx_cartproducts_paypal.category.hiring_services', 'hiring_services'],
			[$LLL . ':tx_cartproducts_paypal.category.hobbies_toys_and_games', 'hobbies_toys_and_games'],
			[$LLL . ':tx_cartproducts_paypal.category.home_and_garden', 'home_and_garden'],
			[$LLL . ':tx_cartproducts_paypal.category.home_audio', 'home_audio'],
			[$LLL . ':tx_cartproducts_paypal.category.home_decor', 'home_decor'],
			[$LLL . ':tx_cartproducts_paypal.category.home_electronics', 'home_electronics'],
			[$LLL . ':tx_cartproducts_paypal.category.hospitals', 'hospitals'],
			[$LLL . ':tx_cartproducts_paypal.category.hotels_motels_inns_resorts', 'hotels_motels_inns_resorts'],
			[$LLL . ':tx_cartproducts_paypal.category.housewares', 'housewares'],
			[$LLL . ':tx_cartproducts_paypal.category.human_parts_and_remains', 'human_parts_and_remains'],
			[$LLL . ':tx_cartproducts_paypal.category.humorous_gifts_and_novelties', 'humorous_gifts_and_novelties'],
			[$LLL . ':tx_cartproducts_paypal.category.hunting', 'hunting'],
			[$LLL . ':tx_cartproducts_paypal.category.ids_licenses_and_passports', 'ids_licenses_and_passports'],
			[$LLL . ':tx_cartproducts_paypal.category.illegal_drugs_and_paraphernalia', 'illegal_drugs_and_paraphernalia'],
			[$LLL . ':tx_cartproducts_paypal.category.industrial', 'industrial'],
			[$LLL . ':tx_cartproducts_paypal.category.industrial_and_manufacturing_supplies', 'industrial_and_manufacturing_supplies'],
			[$LLL . ':tx_cartproducts_paypal.category.insurance_auto_and_home', 'insurance_auto_and_home'],
			[$LLL . ':tx_cartproducts_paypal.category.insurance_direct', 'insurance_direct'],
			[$LLL . ':tx_cartproducts_paypal.category.insurance_life_and_annuity', 'insurance_life_and_annuity'],
			[$LLL . ':tx_cartproducts_paypal.category.insurance_sales_underwriting', 'insurance_sales_underwriting'],
			[$LLL . ':tx_cartproducts_paypal.category.insurance_underwriting_premiums', 'insurance_underwriting_premiums'],
			[$LLL . ':tx_cartproducts_paypal.category.internet_and_network_services', 'internet_and_network_services'],
			[$LLL . ':tx_cartproducts_paypal.category.intra_company_purchases', 'intra_company_purchases'],
			[$LLL . ':tx_cartproducts_paypal.category.laboratories_dental_medical', 'laboratories_dental_medical'],
			[$LLL . ':tx_cartproducts_paypal.category.landscaping', 'landscaping'],
			[$LLL . ':tx_cartproducts_paypal.category.landscaping_and_horticultural_services', 'landscaping_and_horticultural_services'],
			[$LLL . ':tx_cartproducts_paypal.category.laundry_cleaning_services', 'laundry_cleaning_services'],
			[$LLL . ':tx_cartproducts_paypal.category.legal', 'legal'],
			[$LLL . ':tx_cartproducts_paypal.category.legal_services_and_attorneys', 'legal_services_and_attorneys'],
			[$LLL . ':tx_cartproducts_paypal.category.local_delivery_service', 'local_delivery_service'],
			[$LLL . ':tx_cartproducts_paypal.category.locksmith', 'locksmith'],
			[$LLL . ':tx_cartproducts_paypal.category.lodging_and_accommodations', 'lodging_and_accommodations'],
			[$LLL . ':tx_cartproducts_paypal.category.lottery_and_contests', 'lottery_and_contests'],
			[$LLL . ':tx_cartproducts_paypal.category.luggage_and_leather_goods', 'luggage_and_leather_goods'],
			[$LLL . ':tx_cartproducts_paypal.category.lumber_and_building_materials', 'lumber_and_building_materials'],
			[$LLL . ':tx_cartproducts_paypal.category.magazines', 'magazines'],
			[$LLL . ':tx_cartproducts_paypal.category.maintenance_and_repair_services', 'maintenance_and_repair_services'],
			[$LLL . ':tx_cartproducts_paypal.category.makeup_and_cosmetics', 'makeup_and_cosmetics'],
			[$LLL . ':tx_cartproducts_paypal.category.manual_cash_disbursements', 'manual_cash_disbursements'],
			[$LLL . ':tx_cartproducts_paypal.category.massage_parlors', 'massage_parlors'],
			[$LLL . ':tx_cartproducts_paypal.category.medical', 'medical'],
			[$LLL . ':tx_cartproducts_paypal.category.medical_and_pharmaceutical', 'medical_and_pharmaceutical'],
			[$LLL . ':tx_cartproducts_paypal.category.medical_care', 'medical_care'],
			[$LLL . ':tx_cartproducts_paypal.category.medical_equipment_and_supplies', 'medical_equipment_and_supplies'],
			[$LLL . ':tx_cartproducts_paypal.category.medical_services', 'medical_services'],
			[$LLL . ':tx_cartproducts_paypal.category.meeting_planners', 'meeting_planners'],
			[$LLL . ':tx_cartproducts_paypal.category.membership_clubs_and_organizations', 'membership_clubs_and_organizations'],
			[$LLL . ':tx_cartproducts_paypal.category.membership_country_clubs_golf', 'membership_country_clubs_golf'],
			[$LLL . ':tx_cartproducts_paypal.category.memorabilia', 'memorabilia'],
			[$LLL . ':tx_cartproducts_paypal.category.men_and_boy_clothing_and_accessory_stores', 'men_and_boy_clothing_and_accessory_stores'],
			[$LLL . ':tx_cartproducts_paypal.category.men_clothing', 'men_clothing'],
			[$LLL . ':tx_cartproducts_paypal.category.merchandise', 'merchandise'],
			[$LLL . ':tx_cartproducts_paypal.category.metaphysical', 'metaphysical'],
			[$LLL . ':tx_cartproducts_paypal.category.militaria', 'militaria'],
			[$LLL . ':tx_cartproducts_paypal.category.military_and_civil_service_uniforms', 'military_and_civil_service_uniforms'],
			[$LLL . ':tx_cartproducts_paypal.category.misc._automotive_aircraft_and_farm_equipment_dealers', 'misc._automotive_aircraft_and_farm_equipment_dealers'],
			[$LLL . ':tx_cartproducts_paypal.category.misc._general_merchandise', 'misc._general_merchandise'],
			[$LLL . ':tx_cartproducts_paypal.category.miscellaneous_general_services', 'miscellaneous_general_services'],
			[$LLL . ':tx_cartproducts_paypal.category.miscellaneous_repair_shops_and_related_services', 'miscellaneous_repair_shops_and_related_services'],
			[$LLL . ':tx_cartproducts_paypal.category.model_kits', 'model_kits'],
			[$LLL . ':tx_cartproducts_paypal.category.money_transfer_member_financial_institution', 'money_transfer_member_financial_institution'],
			[$LLL . ':tx_cartproducts_paypal.category.money_transfer_merchant', 'money_transfer_merchant'],
			[$LLL . ':tx_cartproducts_paypal.category.motion_picture_theaters', 'motion_picture_theaters'],
			[$LLL . ':tx_cartproducts_paypal.category.motor_freight_carriers_and_trucking', 'motor_freight_carriers_and_trucking'],
			[$LLL . ':tx_cartproducts_paypal.category.motor_home_and_recreational_vehicle_rental', 'motor_home_and_recreational_vehicle_rental'],
			[$LLL . ':tx_cartproducts_paypal.category.motor_homes_dealers', 'motor_homes_dealers'],
			[$LLL . ':tx_cartproducts_paypal.category.motor_vehicle_supplies_and_new_parts', 'motor_vehicle_supplies_and_new_parts'],
			[$LLL . ':tx_cartproducts_paypal.category.motorcycle_dealers', 'motorcycle_dealers'],
			[$LLL . ':tx_cartproducts_paypal.category.motorcycles', 'motorcycles'],
			[$LLL . ':tx_cartproducts_paypal.category.movie', 'movie'],
			[$LLL . ':tx_cartproducts_paypal.category.movie_tickets', 'movie_tickets'],
			[$LLL . ':tx_cartproducts_paypal.category.moving_and_storage', 'moving_and_storage'],
			[$LLL . ':tx_cartproducts_paypal.category.multi_level_marketing', 'multi_level_marketing'],
			[$LLL . ':tx_cartproducts_paypal.category.music_cds_cassettes_and_albums', 'music_cds_cassettes_and_albums'],
			[$LLL . ':tx_cartproducts_paypal.category.music_store_instruments_and_sheet_music', 'music_store_instruments_and_sheet_music'],
			[$LLL . ':tx_cartproducts_paypal.category.networking', 'networking'],
			[$LLL . ':tx_cartproducts_paypal.category.new_age', 'new_age'],
			[$LLL . ':tx_cartproducts_paypal.category.new_parts_and_supplies_motor_vehicle', 'new_parts_and_supplies_motor_vehicle'],
			[$LLL . ':tx_cartproducts_paypal.category.news_dealers_and_newstands', 'news_dealers_and_newstands'],
			[$LLL . ':tx_cartproducts_paypal.category.non_durable_goods', 'non_durable_goods'],
			[$LLL . ':tx_cartproducts_paypal.category.non_fiction', 'non_fiction'],
			[$LLL . ':tx_cartproducts_paypal.category.non_profit_political_and_religion', 'non_profit_political_and_religion'],
			[$LLL . ':tx_cartproducts_paypal.category.nonprofit', 'nonprofit'],
			[$LLL . ':tx_cartproducts_paypal.category.novelties', 'novelties'],
			[$LLL . ':tx_cartproducts_paypal.category.oem_software', 'oem_software'],
			[$LLL . ':tx_cartproducts_paypal.category.office_supplies_and_equipment', 'office_supplies_and_equipment'],
			[$LLL . ':tx_cartproducts_paypal.category.online_dating', 'online_dating'],
			[$LLL . ':tx_cartproducts_paypal.category.online_gaming', 'online_gaming'],
			[$LLL . ':tx_cartproducts_paypal.category.online_gaming_currency', 'online_gaming_currency'],
			[$LLL . ':tx_cartproducts_paypal.category.online_services', 'online_services'],
			[$LLL . ':tx_cartproducts_paypal.category.ooutbound_telemarketing_merch', 'ooutbound_telemarketing_merch'],
			[$LLL . ':tx_cartproducts_paypal.category.ophthalmologists_optometrist', 'ophthalmologists_optometrist'],
			[$LLL . ':tx_cartproducts_paypal.category.opticians_and_dispensing', 'opticians_and_dispensing'],
			[$LLL . ':tx_cartproducts_paypal.category.orthopedic_goods_prosthetics', 'orthopedic_goods_prosthetics'],
			[$LLL . ':tx_cartproducts_paypal.category.osteopaths', 'osteopaths'],
			[$LLL . ':tx_cartproducts_paypal.category.other', 'other'],
			[$LLL . ':tx_cartproducts_paypal.category.package_tour_operators', 'package_tour_operators'],
			[$LLL . ':tx_cartproducts_paypal.category.paintball', 'paintball'],
			[$LLL . ':tx_cartproducts_paypal.category.paints_varnishes_and_supplies', 'paints_varnishes_and_supplies'],
			[$LLL . ':tx_cartproducts_paypal.category.parking_lots_and_garages', 'parking_lots_and_garages'],
			[$LLL . ':tx_cartproducts_paypal.category.parts_and_accessories', 'parts_and_accessories'],
			[$LLL . ':tx_cartproducts_paypal.category.pawn_shops', 'pawn_shops'],
			[$LLL . ':tx_cartproducts_paypal.category.paycheck_lender_or_cash_advance', 'paycheck_lender_or_cash_advance'],
			[$LLL . ':tx_cartproducts_paypal.category.peripherals', 'peripherals'],
			[$LLL . ':tx_cartproducts_paypal.category.personalized_gifts', 'personalized_gifts'],
			[$LLL . ':tx_cartproducts_paypal.category.pet_shops_pet_food_and_supplies', 'pet_shops_pet_food_and_supplies'],
			[$LLL . ':tx_cartproducts_paypal.category.petroleum_and_petroleum_products', 'petroleum_and_petroleum_products'],
			[$LLL . ':tx_cartproducts_paypal.category.pets_and_animals', 'pets_and_animals'],
			[$LLL . ':tx_cartproducts_paypal.category.photofinishing_laboratories_photo_developing', 'photofinishing_laboratories_photo_developing'],
			[$LLL . ':tx_cartproducts_paypal.category.photographic_studios_portraits', 'photographic_studios_portraits'],
			[$LLL . ':tx_cartproducts_paypal.category.photography', 'photography'],
			[$LLL . ':tx_cartproducts_paypal.category.physical_good', 'physical_good'],
			[$LLL . ':tx_cartproducts_paypal.category.picture_video_production', 'picture_video_production'],
			[$LLL . ':tx_cartproducts_paypal.category.piece_goods_notions_and_other_dry_goods', 'piece_goods_notions_and_other_dry_goods'],
			[$LLL . ':tx_cartproducts_paypal.category.plants_and_seeds', 'plants_and_seeds'],
			[$LLL . ':tx_cartproducts_paypal.category.plumbing_and_heating_equipments_and_supplies', 'plumbing_and_heating_equipments_and_supplies'],
			[$LLL . ':tx_cartproducts_paypal.category.police_related_items', 'police_related_items'],
			[$LLL . ':tx_cartproducts_paypal.category.political_organizations', 'political_organizations'],
			[$LLL . ':tx_cartproducts_paypal.category.postal_services_government_only', 'postal_services_government_only'],
			[$LLL . ':tx_cartproducts_paypal.category.posters', 'posters'],
			[$LLL . ':tx_cartproducts_paypal.category.prepaid_and_stored_value_cards', 'prepaid_and_stored_value_cards'],
			[$LLL . ':tx_cartproducts_paypal.category.prescription_drugs', 'prescription_drugs'],
			[$LLL . ':tx_cartproducts_paypal.category.promotional_items', 'promotional_items'],
			[$LLL . ':tx_cartproducts_paypal.category.public_warehousing_and_storage', 'public_warehousing_and_storage'],
			[$LLL . ':tx_cartproducts_paypal.category.publishing_and_printing', 'publishing_and_printing'],
			[$LLL . ':tx_cartproducts_paypal.category.publishing_services', 'publishing_services'],
			[$LLL . ':tx_cartproducts_paypal.category.radar_dectors', 'radar_dectors'],
			[$LLL . ':tx_cartproducts_paypal.category.radio_television_and_stereo_repair', 'radio_television_and_stereo_repair'],
			[$LLL . ':tx_cartproducts_paypal.category.real_estate', 'real_estate'],
			[$LLL . ':tx_cartproducts_paypal.category.real_estate_agent', 'real_estate_agent'],
			[$LLL . ':tx_cartproducts_paypal.category.real_estate_agents_and_managers_rentals', 'real_estate_agents_and_managers_rentals'],
			[$LLL . ':tx_cartproducts_paypal.category.religion_and_spirituality_for_profit', 'religion_and_spirituality_for_profit'],
			[$LLL . ':tx_cartproducts_paypal.category.religious', 'religious'],
			[$LLL . ':tx_cartproducts_paypal.category.religious_organizations', 'religious_organizations'],
			[$LLL . ':tx_cartproducts_paypal.category.remittance', 'remittance'],
			[$LLL . ':tx_cartproducts_paypal.category.rental_property_management', 'rental_property_management'],
			[$LLL . ':tx_cartproducts_paypal.category.residential', 'residential'],
			[$LLL . ':tx_cartproducts_paypal.category.retail', 'retail'],
			[$LLL . ':tx_cartproducts_paypal.category.retail_fine_jewelry_and_watches', 'retail_fine_jewelry_and_watches'],
			[$LLL . ':tx_cartproducts_paypal.category.reupholstery_and_furniture_repair', 'reupholstery_and_furniture_repair'],
			[$LLL . ':tx_cartproducts_paypal.category.rings', 'rings'],
			[$LLL . ':tx_cartproducts_paypal.category.roofing_siding_sheet_metal', 'roofing_siding_sheet_metal'],
			[$LLL . ':tx_cartproducts_paypal.category.rugs_and_carpets', 'rugs_and_carpets'],
			[$LLL . ':tx_cartproducts_paypal.category.schools_and_colleges', 'schools_and_colleges'],
			[$LLL . ':tx_cartproducts_paypal.category.science_fiction', 'science_fiction'],
			[$LLL . ':tx_cartproducts_paypal.category.scrapbooking', 'scrapbooking'],
			[$LLL . ':tx_cartproducts_paypal.category.sculptures', 'sculptures'],
			[$LLL . ':tx_cartproducts_paypal.category.securities_brokers_and_dealers', 'securities_brokers_and_dealers'],
			[$LLL . ':tx_cartproducts_paypal.category.security_and_surveillance', 'security_and_surveillance'],
			[$LLL . ':tx_cartproducts_paypal.category.security_and_surveillance_equipment', 'security_and_surveillance_equipment'],
			[$LLL . ':tx_cartproducts_paypal.category.security_brokers_and_dealers', 'security_brokers_and_dealers'],
			[$LLL . ':tx_cartproducts_paypal.category.seminars', 'seminars'],
			[$LLL . ':tx_cartproducts_paypal.category.service_stations', 'service_stations'],
			[$LLL . ':tx_cartproducts_paypal.category.services', 'services'],
			[$LLL . ':tx_cartproducts_paypal.category.sewing_needlework_fabric_and_piece_goods_stores', 'sewing_needlework_fabric_and_piece_goods_stores'],
			[$LLL . ':tx_cartproducts_paypal.category.shipping_and_packing', 'shipping_and_packing'],
			[$LLL . ':tx_cartproducts_paypal.category.shoe_repair_hat_cleaning', 'shoe_repair_hat_cleaning'],
			[$LLL . ':tx_cartproducts_paypal.category.shoe_stores', 'shoe_stores'],
			[$LLL . ':tx_cartproducts_paypal.category.shoes', 'shoes'],
			[$LLL . ':tx_cartproducts_paypal.category.snowmobile_dealers', 'snowmobile_dealers'],
			[$LLL . ':tx_cartproducts_paypal.category.software', 'software'],
			[$LLL . ':tx_cartproducts_paypal.category.specialty_and_misc._food_stores', 'specialty_and_misc._food_stores'],
			[$LLL . ':tx_cartproducts_paypal.category.specialty_cleaning_polishing_and_sanitation_preparations', 'specialty_cleaning_polishing_and_sanitation_preparations'],
			[$LLL . ':tx_cartproducts_paypal.category.specialty_or_rare_pets', 'specialty_or_rare_pets'],
			[$LLL . ':tx_cartproducts_paypal.category.sport_games_and_toys', 'sport_games_and_toys'],
			[$LLL . ':tx_cartproducts_paypal.category.sporting_and_recreational_camps', 'sporting_and_recreational_camps'],
			[$LLL . ':tx_cartproducts_paypal.category.sporting_goods', 'sporting_goods'],
			[$LLL . ':tx_cartproducts_paypal.category.sports_and_outdoors', 'sports_and_outdoors'],
			[$LLL . ':tx_cartproducts_paypal.category.sports_and_recreation', 'sports_and_recreation'],
			[$LLL . ':tx_cartproducts_paypal.category.stamp_and_coin', 'stamp_and_coin'],
			[$LLL . ':tx_cartproducts_paypal.category.stationary_printing_and_writing_paper', 'stationary_printing_and_writing_paper'],
			[$LLL . ':tx_cartproducts_paypal.category.stenographic_and_secretarial_support_services', 'stenographic_and_secretarial_support_services'],
			[$LLL . ':tx_cartproducts_paypal.category.stocks_bonds_securities_and_related_certificates', 'stocks_bonds_securities_and_related_certificates'],
			[$LLL . ':tx_cartproducts_paypal.category.stored_value_cards', 'stored_value_cards'],
			[$LLL . ':tx_cartproducts_paypal.category.supplies', 'supplies'],
			[$LLL . ':tx_cartproducts_paypal.category.supplies_and_toys', 'supplies_and_toys'],
			[$LLL . ':tx_cartproducts_paypal.category.surveillance_equipment', 'surveillance_equipment'],
			[$LLL . ':tx_cartproducts_paypal.category.swimming_pools_and_spas', 'swimming_pools_and_spas'],
			[$LLL . ':tx_cartproducts_paypal.category.swimming_pools_sales_supplies_services', 'swimming_pools_sales_supplies_services'],
			[$LLL . ':tx_cartproducts_paypal.category.tailors_and_alterations', 'tailors_and_alterations'],
			[$LLL . ':tx_cartproducts_paypal.category.tax_payments', 'tax_payments'],
			[$LLL . ':tx_cartproducts_paypal.category.tax_payments_government_agencies', 'tax_payments_government_agencies'],
			[$LLL . ':tx_cartproducts_paypal.category.taxicabs_and_limousines', 'taxicabs_and_limousines'],
			[$LLL . ':tx_cartproducts_paypal.category.telecommunication_services', 'telecommunication_services'],
			[$LLL . ':tx_cartproducts_paypal.category.telephone_cards', 'telephone_cards'],
			[$LLL . ':tx_cartproducts_paypal.category.telephone_equipment', 'telephone_equipment'],
			[$LLL . ':tx_cartproducts_paypal.category.telephone_services', 'telephone_services'],
			[$LLL . ':tx_cartproducts_paypal.category.theater', 'theater'],
			[$LLL . ':tx_cartproducts_paypal.category.tire_retreading_and_repair', 'tire_retreading_and_repair'],
			[$LLL . ':tx_cartproducts_paypal.category.toll_or_bridge_fees', 'toll_or_bridge_fees'],
			[$LLL . ':tx_cartproducts_paypal.category.tools_and_equipment', 'tools_and_equipment'],
			[$LLL . ':tx_cartproducts_paypal.category.tourist_attractions_and_exhibits', 'tourist_attractions_and_exhibits'],
			[$LLL . ':tx_cartproducts_paypal.category.towing_service', 'towing_service'],
			[$LLL . ':tx_cartproducts_paypal.category.toys_and_games', 'toys_and_games'],
			[$LLL . ':tx_cartproducts_paypal.category.trade_and_vocational_schools', 'trade_and_vocational_schools'],
			[$LLL . ':tx_cartproducts_paypal.category.trademark_infringement', 'trademark_infringement'],
			[$LLL . ':tx_cartproducts_paypal.category.trailer_parks_and_campgrounds', 'trailer_parks_and_campgrounds'],
			[$LLL . ':tx_cartproducts_paypal.category.training_services', 'training_services'],
			[$LLL . ':tx_cartproducts_paypal.category.transportation_services', 'transportation_services'],
			[$LLL . ':tx_cartproducts_paypal.category.travel', 'travel'],
			[$LLL . ':tx_cartproducts_paypal.category.truck_and_utility_trailer_rentals', 'truck_and_utility_trailer_rentals'],
			[$LLL . ':tx_cartproducts_paypal.category.truck_stop', 'truck_stop'],
			[$LLL . ':tx_cartproducts_paypal.category.typesetting_plate_making_and_related_services', 'typesetting_plate_making_and_related_services'],
			[$LLL . ':tx_cartproducts_paypal.category.used_merchandise_and_secondhand_stores', 'used_merchandise_and_secondhand_stores'],
			[$LLL . ':tx_cartproducts_paypal.category.used_parts_motor_vehicle', 'used_parts_motor_vehicle'],
			[$LLL . ':tx_cartproducts_paypal.category.utilities', 'utilities'],
			[$LLL . ':tx_cartproducts_paypal.category.utilities_electric_gas_water_sanitary', 'utilities_electric_gas_water_sanitary'],
			[$LLL . ':tx_cartproducts_paypal.category.variety_stores', 'variety_stores'],
			[$LLL . ':tx_cartproducts_paypal.category.vehicle_sales', 'vehicle_sales'],
			[$LLL . ':tx_cartproducts_paypal.category.vehicle_service_and_accessories', 'vehicle_service_and_accessories'],
			[$LLL . ':tx_cartproducts_paypal.category.video_equipment', 'video_equipment'],
			[$LLL . ':tx_cartproducts_paypal.category.video_game_arcades_establish', 'video_game_arcades_establish'],
			[$LLL . ':tx_cartproducts_paypal.category.video_games_and_systems', 'video_games_and_systems'],
			[$LLL . ':tx_cartproducts_paypal.category.video_tape_rental_stores', 'video_tape_rental_stores'],
			[$LLL . ':tx_cartproducts_paypal.category.vintage_and_collectible_vehicles', 'vintage_and_collectible_vehicles'],
			[$LLL . ':tx_cartproducts_paypal.category.vintage_and_collectibles', 'vintage_and_collectibles'],
			[$LLL . ':tx_cartproducts_paypal.category.vitamins_and_supplements', 'vitamins_and_supplements'],
			[$LLL . ':tx_cartproducts_paypal.category.vocational_and_trade_schools', 'vocational_and_trade_schools'],
			[$LLL . ':tx_cartproducts_paypal.category.watch_clock_and_jewelry_repair', 'watch_clock_and_jewelry_repair'],
			[$LLL . ':tx_cartproducts_paypal.category.web_hosting_and_design', 'web_hosting_and_design'],
			[$LLL . ':tx_cartproducts_paypal.category.welding_repair', 'welding_repair'],
			[$LLL . ':tx_cartproducts_paypal.category.wholesale_clubs', 'wholesale_clubs'],
			[$LLL . ':tx_cartproducts_paypal.category.wholesale_florist_suppliers', 'wholesale_florist_suppliers'],
			[$LLL . ':tx_cartproducts_paypal.category.wholesale_prescription_drugs', 'wholesale_prescription_drugs'],
			[$LLL . ':tx_cartproducts_paypal.category.wildlife_products', 'wildlife_products'],
			[$LLL . ':tx_cartproducts_paypal.category.wire_transfer', 'wire_transfer'],
			[$LLL . ':tx_cartproducts_paypal.category.wire_transfer_and_money_order', 'wire_transfer_and_money_order'],
			[$LLL . ':tx_cartproducts_paypal.category.women_accessory_speciality', 'women_accessory_speciality'],
			[$LLL . ':tx_cartproducts_paypal.category.women_clothing', 'women_clothing']
		];
	}

	public static function setupFailure():array
	{
		$LLL = self::LLL();
		return [
			[$LLL . ':tx_cartproducts_domain_model_order_product.paypal_setup_failure.cancel', 'cancel'],
			[$LLL . ':tx_cartproducts_domain_model_order_product.paypal_setup_failure.continue', 'continue'],
		];
	}
}
